@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2021 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -92,34 +92,34 @@ cmor_check_eval(int vlistID, int nvars, const std::vector<CmorVar> &vars)
           vlistInqVarName(vlistID, varID, varname);
 
           if (n_lower_min > 0)
-            cdoWarning("Invalid value(s) detected for variable '%s': %ld values were lower than minimum valid value (%.4g).",
-                       varname, n_lower_min, var.valid_min);
+            cdo_warning("Invalid value(s) detected for variable '%s': %ld values were lower than minimum valid value (%.4g).",
+                        varname, n_lower_min, var.valid_min);
           if (n_greater_max > 0)
-            cdoWarning("Invalid value(s) detected for variable '%s': %ld values were greater than maximum valid value (%.4g).",
-                       varname, n_greater_max, var.valid_max);
+            cdo_warning("Invalid value(s) detected for variable '%s': %ld values were greater than maximum valid value (%.4g).",
+                        varname, n_greater_max, var.valid_max);
 
           if (var.check_min_mean_abs)
             {
               if (amean < .1 * var.ok_min_mean_abs)
-                cdoWarning("Invalid Absolute Mean for variable '%s' (%.5g) is lower by more than an order of magnitude than "
-                           "minimum allowed: %.4g",
-                           varname, amean, var.ok_min_mean_abs);
+                cdo_warning("Invalid Absolute Mean for variable '%s' (%.5g) is lower by more than an order of magnitude than "
+                            "minimum allowed: %.4g",
+                            varname, amean, var.ok_min_mean_abs);
 
               if (amean < var.ok_min_mean_abs)
-                cdoWarning("Invalid Absolute Mean for variable '%s' (%.5g) is lower than minimum allowed: %.4g", varname, amean,
-                           var.ok_min_mean_abs);
+                cdo_warning("Invalid Absolute Mean for variable '%s' (%.5g) is lower than minimum allowed: %.4g", varname, amean,
+                            var.ok_min_mean_abs);
             }
 
           if (var.check_max_mean_abs)
             {
               if (amean > 10. * var.ok_max_mean_abs)
-                cdoWarning("Invalid Absolute Mean for variable '%s' (%.5g) is greater by more than an order of magnitude than "
-                           "maximum allowed: %.4g",
-                           varname, amean, var.ok_max_mean_abs);
+                cdo_warning("Invalid Absolute Mean for variable '%s' (%.5g) is greater by more than an order of magnitude than "
+                            "maximum allowed: %.4g",
+                            varname, amean, var.ok_max_mean_abs);
 
               if (amean > var.ok_max_mean_abs)
-                cdoWarning("Invalid Absolute Mean for variable '%s' (%.5g) is greater than maximum allowed: %.4g", varname, amean,
-                           var.ok_max_mean_abs);
+                cdo_warning("Invalid Absolute Mean for variable '%s' (%.5g) is greater than maximum allowed: %.4g", varname, amean,
+                            var.ok_max_mean_abs);
             }
         }
     }
@@ -187,7 +187,7 @@ applyCmorList(PMList &pmlist, int nvars, int vlistID2, std::vector<CmorVar> &var
             if (key == "missing_value")
               {
                 lmissval = true;
-                missval = parameter2double(value);
+                missval = parameter_to_double(value);
               }
             else if (key == "table_id" || key == "modeling_realm" || key == "realm" || key == "project_id" || key == "frequency")
               {
@@ -232,36 +232,36 @@ applyCmorList(PMList &pmlist, int nvars, int vlistID2, std::vector<CmorVar> &var
               if      (key == "standard_name") cdiDefKeyString(vlistID2, varID, CDI_KEY_STDNAME, value_cstr);
               else if (key == "long_name") cdiDefKeyString(vlistID2, varID, CDI_KEY_LONGNAME, value_cstr);
               else if (key == "units") cdo_define_var_units(var, vlistID2, varID, value_cstr);
-              else if (key == "name") ; // cdiDefKeyString(vlistID2, varID, CDI_KEY_NAME, parameter2word(value.c_str()));
+              else if (key == "name") ; // cdiDefKeyString(vlistID2, varID, CDI_KEY_NAME, parameter_to_word(value.c_str()));
               else if (key == "out_name")
                 {
-                  const auto outname = parameter2word(value.c_str());
+                  const auto outname = parameter_to_word(value.c_str());
                   if (!cdo_cmpstr(var.name, outname))
                     {
                       cdiDefKeyString(vlistID2, varID, CDI_KEY_NAME, outname);
                       cdiDefAttTxt(vlistID2, varID, "original_name", (int) strlen(var.name), var.name);
                     }
                 }
-              else if (key == "param") vlistDefVarParam(vlistID2, varID, stringToParam(parameter2word(value.c_str())));
-              else if (key == "out_param") vlistDefVarParam(vlistID2, varID, stringToParam(parameter2word(value.c_str())));
+              else if (key == "param") vlistDefVarParam(vlistID2, varID, string_to_param(parameter_to_word(value.c_str())));
+              else if (key == "out_param") vlistDefVarParam(vlistID2, varID, string_to_param(parameter_to_word(value.c_str())));
               else if (key == "comment") cdiDefAttTxt(vlistID2, varID, key.c_str(), (int) value.size(), value_cstr);
               else if (key == "cell_methods") cdiDefAttTxt(vlistID2, varID, key.c_str(), (int) value.size(), value_cstr);
               else if (key == "cell_measures") cdiDefAttTxt(vlistID2, varID, key.c_str(), (int) value.size(), value_cstr);
-              else if (key == "delete") var.remove = parameter2bool(value);
-              else if (key == "convert") var.convert = parameter2bool(value);
+              else if (key == "delete") var.remove = parameter_to_bool(value);
+              else if (key == "convert") var.convert = parameter_to_bool(value);
               else if (key == "factor")
                 {
                   var.lfactor = true;
-                  var.factor = parameter2double(value);
-                  if (Options::cdoVerbose) cdoPrint("%s - scale factor %g", varname, var.factor);
+                  var.factor = parameter_to_double(value);
+                  if (Options::cdoVerbose) cdo_print("%s - scale factor %g", varname, var.factor);
                 }
               else if (key == "missval" || key == "missing_value")
                 {
-                  missval = parameter2double(value);
+                  missval = parameter_to_double(value);
                   auto missval_old = vlistInqVarMissval(vlistID2, varID);
                   if (!DBL_IS_EQUAL(missval, missval_old))
                     {
-                      if (Options::cdoVerbose) cdoPrint("%s - change missval from %g to %g", varname, missval_old, missval);
+                      if (Options::cdoVerbose) cdo_print("%s - change missval from %g to %g", varname, missval_old, missval);
                       var.changemissval = true;
                       var.missval_old = missval_old;
                       vlistDefVarMissval(vlistID2, varID, missval);
@@ -270,31 +270,31 @@ applyCmorList(PMList &pmlist, int nvars, int vlistID2, std::vector<CmorVar> &var
               else if (key == "valid_min")
                 {
                   lvalid_min = true;
-                  var.valid_min = parameter2double(value);
+                  var.valid_min = parameter_to_double(value);
                 }
               else if (key == "valid_max")
                 {
                   lvalid_max = true;
-                  var.valid_max = parameter2double(value);
+                  var.valid_max = parameter_to_double(value);
                 }
               else if (key == "ok_min_mean_abs")
                 {
                   var.check_min_mean_abs = true;
-                  var.ok_min_mean_abs = parameter2double(value);
+                  var.ok_min_mean_abs = parameter_to_double(value);
                 }
               else if (key == "ok_max_mean_abs")
                 {
                   var.check_max_mean_abs = true;
-                  var.ok_max_mean_abs = parameter2double(value);
+                  var.ok_max_mean_abs = parameter_to_double(value);
                 }
               else if (key == "datatype" || key == "type")
                 {
-                  const auto datatype = cdi_str2datatype(parameter2word(value.c_str()));
+                  const auto datatype = cdo_str_to_datatype(parameter_to_word(value.c_str()));
                   if (datatype != -1) vlistDefVarDatatype(vlistID2, varID, datatype);
                 }
               else
                 {
-                  if (Options::cdoVerbose) cdoPrint("Attribute %s:%s not supported!", varname, key.c_str());
+                  if (Options::cdoVerbose) cdo_print("Attribute %s:%s not supported!", varname, key.c_str());
                 }
               // clang-format on
             }
@@ -303,7 +303,7 @@ applyCmorList(PMList &pmlist, int nvars, int vlistID2, std::vector<CmorVar> &var
         }
       else
         {
-          cdoPrint("Variable %s not found in CMOR table!", varname);
+          cdo_print("Variable %s not found in CMOR table!", varname);
         }
     }
 }
@@ -313,33 +313,33 @@ CMOR_lite(void *process)
 {
   bool delvars = false;
 
-  cdoInitialize(process);
+  cdo_initialize(process);
 
   Options::CMOR_Mode = 1;
   if (Options::CMOR_Mode) cdiDefGlobal("CMOR_MODE", Options::CMOR_Mode);
 
-  cdoOperatorAdd("cmorlite", 0, 0, "parameter table name");
+  cdo_operator_add("cmorlite", 0, 0, "parameter table name");
 
-  const auto operatorID = cdoOperatorID();
+  const auto operatorID = cdo_operator_id();
 
-  operatorInputArg(cdoOperatorEnter(operatorID));
+  operator_input_arg(cdo_operator_enter(operatorID));
 
-  if (operatorArgc() < 1) cdoAbort("Too few arguments!");
+  if (cdo_operator_argc() < 1) cdo_abort("Too few arguments!");
 
   bool convert_data = false;
-  if (operatorArgc() == 2)
+  if (cdo_operator_argc() == 2)
     {
-      if (cdoOperatorArgv(1) == "convert")
+      if (cdo_operator_argv(1) == "convert")
         convert_data = true;
       else
-        cdoAbort("Unknown parameter: >%s<", cdoOperatorArgv(1).c_str());
+        cdo_abort("Unknown parameter: >%s<", cdo_operator_argv(1).c_str());
     }
 
-  if (operatorArgc() > 2) cdoAbort("Too many arguments!");
+  if (cdo_operator_argc() > 2) cdo_abort("Too many arguments!");
 
-  const auto streamID1 = cdoOpenRead(0);
+  const auto streamID1 = cdo_open_read(0);
 
-  const auto vlistID1 = cdoStreamInqVlist(streamID1);
+  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
   auto vlistID2 = vlistDuplicate(vlistID1);
 
   const auto nvars = vlistNvars(vlistID2);
@@ -348,12 +348,12 @@ CMOR_lite(void *process)
   if (convert_data)
     for (int varID = 0; varID < nvars; ++varID) vars[varID].convert = true;
 
-  const auto filename = cdoOperatorArgv(0).c_str();
+  const auto filename = cdo_operator_argv(0).c_str();
   auto fp = fopen(filename, "r");
-  if (fp == nullptr) cdoAbort("Open failed on: %s\n", filename);
+  if (fp == nullptr) cdo_abort("Open failed on: %s\n", filename);
 
   PMList pmlist;
-  pmlist.readCmortable(fp, filename);
+  pmlist.read_cmor_table(fp, filename);
   fclose(fp);
 
   applyCmorList(pmlist, nvars, vlistID2, vars);
@@ -388,12 +388,12 @@ CMOR_lite(void *process)
         }
 
       const auto vlistIDx = vlistCreate();
-      cdoVlistCopyFlag(vlistIDx, vlistID2);
+      cdo_vlist_copy_flag(vlistIDx, vlistID2);
 
       vlistDestroy(vlistID2);
 
       vlistID2 = vlistIDx;
-      if (vlistNvars(vlistID2) == 0) cdoAbort("No variable selected!");
+      if (vlistNvars(vlistID2) == 0) cdo_abort("No variable selected!");
     }
 
   for (int varID = 0; varID < nvars; ++varID)
@@ -401,7 +401,7 @@ CMOR_lite(void *process)
       auto &var = vars[varID];
       if (!var.convert) var.changeunits = false;
       if (var.changeunits)
-        cdoConvertUnits(&var.ut_converter, &var.changeunits, (char *) &var.units, (char *) &var.units_old, var.name);
+        cdo_convert_units(&var.ut_converter, &var.changeunits, (char *) &var.units, (char *) &var.units_old, var.name);
     }
 
   const auto taxisID1 = vlistInqTaxis(vlistID1);
@@ -409,8 +409,8 @@ CMOR_lite(void *process)
   vlistDefTaxis(vlistID2, taxisID2);
 
   /* vlistPrint(vlistID2);*/
-  const auto streamID2 = cdoOpenWrite(1);
-  cdoDefVlist(streamID2, vlistID2);
+  const auto streamID2 = cdo_open_write(1);
+  cdo_def_vlist(streamID2, vlistID2);
 
   auto gridsizemax = vlistGridsizeMax(vlistID1);
   if (vlistNumber(vlistID1) != CDI_REAL) gridsizemax *= 2;
@@ -419,19 +419,19 @@ CMOR_lite(void *process)
   int tsID = 0;
   while (true)
     {
-      const auto nrecs = cdoStreamInqTimestep(streamID1, tsID);
+      const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      taxisCopyTimestep(taxisID2, taxisID1);
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
 
-      cdoDefTimestep(streamID2, tsID);
+      cdo_def_timestep(streamID2, tsID);
 
       cmor_check_init(nvars, vars);
 
       for (int recID = 0; recID < nrecs; recID++)
         {
           int varID, levelID;
-          cdoInqRecord(streamID1, &varID, &levelID);
+          cdo_inq_record(streamID1, &varID, &levelID);
 
           auto &var = vars[varID];
           auto varID2 = varID;
@@ -448,10 +448,10 @@ CMOR_lite(void *process)
                 }
             }
 
-          cdoDefRecord(streamID2, varID2, levelID2);
+          cdo_def_record(streamID2, varID2, levelID2);
 
-          size_t nmiss; 
-          cdoReadRecord(streamID1, array.data(), &nmiss);
+          size_t nmiss;
+          cdo_read_record(streamID1, array.data(), &nmiss);
 
           const auto missval = varList2[varID2].missval;
           auto gridsize = varList2[varID2].gridsize;
@@ -487,14 +487,14 @@ CMOR_lite(void *process)
                 }
               if (nerr)
                 {
-                  cdoWarning("Udunits: Error converting units from [%s] to [%s], parameter: %s", var.units_old, var.units,
-                             var.name);
+                  cdo_warning("Udunits: Error converting units from [%s] to [%s], parameter: %s", var.units_old, var.units,
+                              var.name);
                   var.changeunits = false;
                 }
             }
 #endif
 
-          cdoWriteRecord(streamID2, array.data(), nmiss);
+          cdo_write_record(streamID2, array.data(), nmiss);
 
           cmor_check_prep(var, gridsize, missval, array.data());
         }
@@ -504,17 +504,17 @@ CMOR_lite(void *process)
       tsID++;
     }
 
-  cdoStreamClose(streamID2);
-  cdoStreamClose(streamID1);
+  cdo_stream_close(streamID2);
+  cdo_stream_close(streamID1);
 
 #ifdef HAVE_UDUNITS2
   for (int varID = 0; varID < nvars; varID++)
-    if (vars[varID].changeunits) cdoConvertFree(vars[varID].ut_converter);
+    if (vars[varID].changeunits) cdo_convert_free(vars[varID].ut_converter);
 
-  cdoConvertDestroy();
+  cdo_convert_destroy();
 #endif
 
-  cdoFinish();
+  cdo_finish();
 
   return 0;
 }
