@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2021 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -71,7 +71,6 @@
 
 #include "cdo_options.h"
 #include "cdo_vlist.h"
-#include "functs.h"
 #include "process_int.h"
 #include "cdo_task.h"
 #include "timer.h"
@@ -102,7 +101,7 @@ struct ReadArguments
   RecordInfo *recList;
   FieldVector2D &vars;
 
-  ReadArguments(FieldVector2D &input_vars) : tsIDnext(0), nrecs(0), recList(nullptr), vars(input_vars) {};
+  ReadArguments(FieldVector2D &input_vars) : tsIDnext(0), nrecs(0), recList(nullptr), vars(input_vars){};
 };
 
 static int num_recs = 0;
@@ -125,7 +124,7 @@ cdoReadTimestep(void *rarg)
 #ifdef USE_CDI_STREAM
       streamInqRecord(streamID, &varID, &levelID);
 #else
-      cdoInqRecord(streamID, &varID, &levelID);
+      cdo_inq_record(streamID, &varID, &levelID);
 #endif
 
       if (tsIDnext == 1 && recList)
@@ -143,9 +142,9 @@ cdoReadTimestep(void *rarg)
         streamReadRecord(streamID, input_vars[varID][levelID].vec_d.data(), &nmiss);
 #else
       if (Options::CDO_Memtype == MemType::Float)
-        cdoReadRecordF(streamID, input_vars[varID][levelID].vec_f.data(), &nmiss);
+        cdo_read_record_f(streamID, input_vars[varID][levelID].vec_f.data(), &nmiss);
       else
-        cdoReadRecord(streamID, input_vars[varID][levelID].vec_d.data(), &nmiss);
+        cdo_read_record(streamID, input_vars[varID][levelID].vec_d.data(), &nmiss);
 #endif
       input_vars[varID][levelID].nmiss = nmiss;
     }
@@ -155,7 +154,7 @@ cdoReadTimestep(void *rarg)
 #ifdef USE_CDI_STREAM
   num_recs = streamInqTimestep(streamID, tsIDnext);
 #else
-  num_recs = cdoStreamInqTimestep(streamID, tsIDnext);
+  num_recs = cdo_stream_inq_timestep(streamID, tsIDnext);
 #endif
 
   return ((void *) &num_recs);
@@ -177,33 +176,33 @@ static void
 addOperators(void)
 {
   // clang-format off
-  cdoOperatorAdd("xtimmin",    func_min,   DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimmax",    func_max,   DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimsum",    func_sum,   DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimmean",   func_mean,  DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimavg",    func_avg,   DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimvar",    func_var,   DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimvar1",   func_var1,  DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimstd",    func_std,   DATE_LEN, nullptr);
-  cdoOperatorAdd("xtimstd1",   func_std1,  DATE_LEN, nullptr);
-  cdoOperatorAdd("xyearmin",   func_min,   YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearmax",   func_max,   YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearsum",   func_sum,   YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearmean",  func_mean,  YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearavg",   func_avg,   YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearvar",   func_var,   YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearvar1",  func_var1,  YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearstd",   func_std,   YEAR_LEN, nullptr);
-  cdoOperatorAdd("xyearstd1",  func_std1,  YEAR_LEN, nullptr);
-  cdoOperatorAdd("xmonmin",    func_min,   MON_LEN, nullptr);
-  cdoOperatorAdd("xmonmax",    func_max,   MON_LEN, nullptr);
-  cdoOperatorAdd("xmonsum",    func_sum,   MON_LEN, nullptr);
-  cdoOperatorAdd("xmonmean",   func_mean,  MON_LEN, nullptr);
-  cdoOperatorAdd("xmonavg",    func_avg,   MON_LEN, nullptr);
-  cdoOperatorAdd("xmonvar",    func_var,   MON_LEN, nullptr);
-  cdoOperatorAdd("xmonvar1",   func_var1,  MON_LEN, nullptr);
-  cdoOperatorAdd("xmonstd",    func_std,   MON_LEN, nullptr);
-  cdoOperatorAdd("xmonstd1",   func_std1,  MON_LEN, nullptr);
+  cdo_operator_add("xtimmin",    FieldFunc_Min,   DATE_LEN, nullptr);
+  cdo_operator_add("xtimmax",    FieldFunc_Max,   DATE_LEN, nullptr);
+  cdo_operator_add("xtimsum",    FieldFunc_Sum,   DATE_LEN, nullptr);
+  cdo_operator_add("xtimmean",   FieldFunc_Mean,  DATE_LEN, nullptr);
+  cdo_operator_add("xtimavg",    FieldFunc_Avg,   DATE_LEN, nullptr);
+  cdo_operator_add("xtimvar",    FieldFunc_Var,   DATE_LEN, nullptr);
+  cdo_operator_add("xtimvar1",   FieldFunc_Var1,  DATE_LEN, nullptr);
+  cdo_operator_add("xtimstd",    FieldFunc_Std,   DATE_LEN, nullptr);
+  cdo_operator_add("xtimstd1",   FieldFunc_Std1,  DATE_LEN, nullptr);
+  cdo_operator_add("xyearmin",   FieldFunc_Min,   YEAR_LEN, nullptr);
+  cdo_operator_add("xyearmax",   FieldFunc_Max,   YEAR_LEN, nullptr);
+  cdo_operator_add("xyearsum",   FieldFunc_Sum,   YEAR_LEN, nullptr);
+  cdo_operator_add("xyearmean",  FieldFunc_Mean,  YEAR_LEN, nullptr);
+  cdo_operator_add("xyearavg",   FieldFunc_Avg,   YEAR_LEN, nullptr);
+  cdo_operator_add("xyearvar",   FieldFunc_Var,   YEAR_LEN, nullptr);
+  cdo_operator_add("xyearvar1",  FieldFunc_Var1,  YEAR_LEN, nullptr);
+  cdo_operator_add("xyearstd",   FieldFunc_Std,   YEAR_LEN, nullptr);
+  cdo_operator_add("xyearstd1",  FieldFunc_Std1,  YEAR_LEN, nullptr);
+  cdo_operator_add("xmonmin",    FieldFunc_Min,   MON_LEN, nullptr);
+  cdo_operator_add("xmonmax",    FieldFunc_Max,   MON_LEN, nullptr);
+  cdo_operator_add("xmonsum",    FieldFunc_Sum,   MON_LEN, nullptr);
+  cdo_operator_add("xmonmean",   FieldFunc_Mean,  MON_LEN, nullptr);
+  cdo_operator_add("xmonavg",    FieldFunc_Avg,   MON_LEN, nullptr);
+  cdo_operator_add("xmonvar",    FieldFunc_Var,   MON_LEN, nullptr);
+  cdo_operator_add("xmonvar1",   FieldFunc_Var1,  MON_LEN, nullptr);
+  cdo_operator_add("xmonstd",    FieldFunc_Std,   MON_LEN, nullptr);
+  cdo_operator_add("xmonstd1",   FieldFunc_Std1,  MON_LEN, nullptr);
   // clang-format on
 }
 
@@ -219,53 +218,53 @@ XTimstat(void *process)
   char indate1[DATE_LEN + 1], indate2[DATE_LEN + 1];
   double vfrac = 1;
 
-  cdoInitialize(process);
+  cdo_initialize(process);
 
   addOperators();
 
-  const auto operatorID = cdoOperatorID();
-  auto operfunc = cdoOperatorF1(operatorID);
-  const auto comparelen = cdoOperatorF2(operatorID);
+  const auto operatorID = cdo_operator_id();
+  auto operfunc = cdo_operator_f1(operatorID);
+  const auto comparelen = cdo_operator_f2(operatorID);
 
-  const auto lmean = (operfunc == func_mean || operfunc == func_avg);
-  const auto lstd = (operfunc == func_std || operfunc == func_std1);
-  auto lvarstd = (lstd || operfunc == func_var || operfunc == func_var1);
+  const auto lmean = (operfunc == FieldFunc_Mean || operfunc == FieldFunc_Avg);
+  const auto lstd = (operfunc == FieldFunc_Std || operfunc == FieldFunc_Std1);
+  auto lvarstd = (lstd || operfunc == FieldFunc_Var || operfunc == FieldFunc_Var1);
   const auto lvars2 = lvarstd;
-  int divisor = (operfunc == func_std1 || operfunc == func_var1);
+  int divisor = (operfunc == FieldFunc_Std1 || operfunc == FieldFunc_Var1);
 
-  auto vfarstdvar_func = lstd ? vfarstd : vfarvar;
-  auto vfarcstdvar_func = lstd ? vfarcstd : vfarcvar;
+  auto field2_stdvar_func = lstd ? field2_std : field2_var;
+  auto fieldc_stdvar_func = lstd ? fieldc_std : fieldc_var;
 
-  if (operfunc == func_mean)
+  if (operfunc == FieldFunc_Mean)
     {
-      const auto oargc = operatorArgc();
+      const auto oargc = cdo_operator_argc();
       if (oargc == 1)
         {
           lvfrac = true;
-          vfrac = parameter2double(cdoOperatorArgv(0));
-          if (Options::cdoVerbose) cdoPrint("Set vfrac to %g", vfrac);
-          if (vfrac < 0 || vfrac > 1) cdoAbort("vfrac out of range!");
+          vfrac = parameter_to_double(cdo_operator_argv(0));
+          if (Options::cdoVerbose) cdo_print("Set vfrac to %g", vfrac);
+          if (vfrac < 0 || vfrac > 1) cdo_abort("vfrac out of range!");
         }
       else if (oargc > 1)
-        cdoAbort("Too many arguments!");
+        cdo_abort("Too many arguments!");
     }
   else
     {
-      operatorCheckArgc(0);
+      operator_check_argc(0);
     }
 
   const int cmplen = DATE_LEN - comparelen;
 
 #ifdef USE_CDI_STREAM
-  const auto streamID1 = streamOpenRead(cdoGetStreamName(0));
+  const auto streamID1 = streamOpenRead(cdo_get_stream_name(0));
   auto vlistID1 = streamInqVlist(streamID1);
 #else
-  const auto streamID1 = cdoOpenRead(0);
-  auto vlistID1 = cdoStreamInqVlist(streamID1);
+  const auto streamID1 = cdo_open_read(0);
+  auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 #endif
 
   const auto vlistID2 = vlistDuplicate(vlistID1);
-  vlistDefineTimestepType(vlistID2, operfunc);
+  vlist_define_timestep_type(vlistID2, operfunc);
 
   if (cmplen == 0) vlistDefNtsteps(vlistID2, 1);
 
@@ -279,16 +278,16 @@ XTimstat(void *process)
 
   vlistSetFrequency(vlistID2, comparelen);
 
-  const auto streamID2 = cdoOpenWrite(1);
-  cdoDefVlist(streamID2, vlistID2);
+  const auto streamID2 = cdo_open_write(1);
+  cdo_def_vlist(streamID2, vlistID2);
 
   if (Options::cdoDiag)
     {
       char filename[8192];
-      strcpy(filename, cdoOperatorName(operatorID));
+      strcpy(filename, cdo_operator_name(operatorID));
       strcat(filename, "_");
-      strcat(filename, cdoGetStreamName(1));
-      streamID3 = cdoOpenWrite(filename);
+      strcat(filename, cdo_get_stream_name(1));
+      streamID3 = cdo_open_write(filename);
 
       vlistID3 = vlistDuplicate(vlistID1);
 
@@ -305,22 +304,22 @@ XTimstat(void *process)
       taxisWithBounds(taxisID3);
       vlistDefTaxis(vlistID3, taxisID3);
 
-      cdoDefVlist(streamID3, vlistID3);
+      cdo_def_vlist(streamID3, vlistID3);
     }
 
   DateTimeList dtlist;
-  dtlist.setStat(timestat_date);
-  dtlist.setCalendar(taxisInqCalendar(taxisID1));
+  dtlist.set_stat(timestat_date);
+  dtlist.set_calendar(taxisInqCalendar(taxisID1));
 
   int FIELD_MEMTYPE = 0;
-  if (operfunc == func_mean && Options::CDO_Memtype == MemType::Float) FIELD_MEMTYPE = FIELD_FLT;
+  if (operfunc == FieldFunc_Mean && Options::CDO_Memtype == MemType::Float) FIELD_MEMTYPE = FIELD_FLT;
   FieldVector3D input_vars(2);
-  fieldsFromVlist(vlistID1, input_vars[0], FIELD_VEC | FIELD_MEMTYPE);
-  fieldsFromVlist(vlistID1, input_vars[1], FIELD_VEC | FIELD_MEMTYPE);
+  fields_from_vlist(vlistID1, input_vars[0], FIELD_VEC | FIELD_MEMTYPE);
+  fields_from_vlist(vlistID1, input_vars[1], FIELD_VEC | FIELD_MEMTYPE);
   FieldVector2D samp1, vars1, vars2;
-  fieldsFromVlist(vlistID1, samp1);
-  fieldsFromVlist(vlistID1, vars1, FIELD_VEC);
-  if (lvars2) fieldsFromVlist(vlistID1, vars2, FIELD_VEC);
+  fields_from_vlist(vlistID1, samp1);
+  fields_from_vlist(vlistID1, vars1, FIELD_VEC);
+  if (lvars2) fields_from_vlist(vlistID1, vars2, FIELD_VEC);
 
   int curFirst = 0;
   int curSecond = 1;
@@ -341,7 +340,7 @@ XTimstat(void *process)
 #ifdef USE_CDI_STREAM
   auto nrecs = streamInqTimestep(streamID1, tsID);
 #else
-  auto nrecs = cdoStreamInqTimestep(streamID1, tsID);
+  auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
 #endif
   int maxrecs = nrecs;
   std::vector<RecordInfo> recList(maxrecs);
@@ -352,9 +351,9 @@ XTimstat(void *process)
       int nsets = 0;
       while (nrecs > 0)
         {
-          dtlist.taxisInqTimestep(taxisID1, nsets);
-          vdate = dtlist.getVdate(nsets);
-          vtime = dtlist.getVtime(nsets);
+          dtlist.taxis_inq_timestep(taxisID1, nsets);
+          vdate = dtlist.get_vdate(nsets);
+          vtime = dtlist.get_vtime(nsets);
 
           if (nsets == 0) SET_DATE(indate2, vdate, vtime);
           SET_DATE(indate1, vdate, vtime);
@@ -403,15 +402,14 @@ XTimstat(void *process)
 
                   const auto nmiss = rinput_var.nmiss;
 
-                  vfarcpy(rvars1, rinput_var);
+                  field_copy(rinput_var, rvars1);
                   rvars1.nmiss = nmiss;
                   if (nmiss || !rsamp1.empty())
                     {
                       const auto fieldsize = rvars1.size;
                       if (rsamp1.empty()) rsamp1.resize(fieldsize);
 
-                      for (size_t i = 0; i < fieldsize; i++)
-                        rsamp1.vec_d[i] = !DBL_IS_EQUAL(rvars1.vec_d[i], rvars1.missval);
+                      for (size_t i = 0; i < fieldsize; i++) rsamp1.vec_d[i] = !DBL_IS_EQUAL(rvars1.vec_d[i], rvars1.missval);
                     }
                 }
             }
@@ -442,8 +440,8 @@ XTimstat(void *process)
                     }
 
                   // clang-format off
-                  if (lvarstd) vfarsumsumq(rvars1, vars2[varID][levelID], rinput_var);
-                  else         vfarfun(rvars1, rinput_var, operfunc);
+                  if (lvarstd) field2_sumsumq(rvars1, vars2[varID][levelID], rinput_var);
+                  else         field2_function(rvars1, rinput_var, operfunc);
                   // clang-format on
                 }
             }
@@ -456,7 +454,7 @@ XTimstat(void *process)
 
                 if (vlistInqVarTimetype(vlistID1, varID) == TIME_CONSTANT) continue;
 
-                vfarmoq(vars2[varID][levelID], vars1[varID][levelID]);
+                field2_moq(vars2[varID][levelID], vars1[varID][levelID]);
               }
 
           vdate0 = vdate;
@@ -480,9 +478,9 @@ XTimstat(void *process)
               if (vlistInqVarTimetype(vlistID1, varID) == TIME_CONSTANT) continue;
 
               if (!samp1[varID][levelID].empty())
-                vfardiv(vars1[varID][levelID], samp1[varID][levelID]);
+                field2_div(vars1[varID][levelID], samp1[varID][levelID]);
               else
-                vfarcdiv(vars1[varID][levelID], (double) nsets);
+                fieldc_div(vars1[varID][levelID], (double) nsets);
             }
         }
       else if (lvarstd)
@@ -499,16 +497,16 @@ XTimstat(void *process)
               const auto &rvars2 = vars2[varID][levelID];
 
               if (!rsamp1.empty())
-                vfarstdvar_func(rvars1, rvars2, rsamp1, divisor);
+                field2_stdvar_func(rvars1, rvars2, rsamp1, divisor);
               else
-                vfarcstdvar_func(rvars1, rvars2, nsets, divisor);
+                fieldc_stdvar_func(rvars1, rvars2, nsets, divisor);
             }
         }
 
       if (Options::cdoVerbose)
-        cdoPrint("%s %s  vfrac = %g, nsets = %d", dateToString(vdate0).c_str(), timeToString(vtime0).c_str(), vfrac, nsets);
+        cdo_print("%s %s  vfrac = %g, nsets = %d", date_to_string(vdate0).c_str(), time_to_string(vtime0).c_str(), vfrac, nsets);
 
-      if (lvfrac && operfunc == func_mean)
+      if (lvfrac && operfunc == FieldFunc_Mean)
         for (int recID = 0; recID < maxrecs; recID++)
           {
             const auto varID = recList[recID].varID;
@@ -531,17 +529,17 @@ XTimstat(void *process)
                       }
                   }
 
-                if (irun) rvars1.nmiss = fieldNumMiss(rvars1);
+                if (irun) rvars1.nmiss = field_num_miss(rvars1);
               }
           }
 
-      dtlist.statTaxisDefTimestep(taxisID2, nsets);
-      cdoDefTimestep(streamID2, otsID);
+      dtlist.stat_taxis_def_timestep(taxisID2, nsets);
+      cdo_def_timestep(streamID2, otsID);
 
       if (Options::cdoDiag)
         {
-          dtlist.statTaxisDefTimestep(taxisID3, nsets);
-          cdoDefTimestep(streamID3, otsID);
+          dtlist.stat_taxis_def_timestep(taxisID3, nsets);
+          cdo_def_timestep(streamID3, otsID);
         }
 
       for (int recID = 0; recID < maxrecs; recID++)
@@ -552,15 +550,15 @@ XTimstat(void *process)
 
           if (otsID && vlistInqVarTimetype(vlistID1, varID) == TIME_CONSTANT) continue;
 
-          cdoDefRecord(streamID2, varID, levelID);
-          cdoWriteRecord(streamID2, rvars1.vec_d.data(), rvars1.nmiss);
+          cdo_def_record(streamID2, varID, levelID);
+          cdo_write_record(streamID2, rvars1.vec_d.data(), rvars1.nmiss);
 
           if (Options::cdoDiag)
             {
               if (!samp1[varID][levelID].empty())
                 {
-                  cdoDefRecord(streamID3, varID, levelID);
-                  cdoWriteRecord(streamID3, samp1[varID][levelID].vec_d.data(), 0);
+                  cdo_def_record(streamID3, varID, levelID);
+                  cdo_write_record(streamID3, samp1[varID][levelID].vec_d.data(), 0);
                 }
             }
         }
@@ -569,17 +567,17 @@ XTimstat(void *process)
       otsID++;
     }
 
-  if (Options::cdoDiag) cdoStreamClose(streamID3);
-  cdoStreamClose(streamID2);
+  if (Options::cdoDiag) cdo_stream_close(streamID3);
+  cdo_stream_close(streamID2);
 #ifdef USE_CDI_STREAM
   streamClose(streamID1);
 #else
-  cdoStreamClose(streamID1);
+  cdo_stream_close(streamID1);
 #endif
 
   if (read_task) delete read_task;
 
-  cdoFinish();
+  cdo_finish();
 
   return nullptr;
 }
