@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2020 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2021 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -60,8 +60,8 @@ remap_set_threshhold(double threshhold)
 static void
 pole_intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool *lcoinc, bool *lthresh, double beglat,
                   double beglon, double endlat, double endlon, double *begseg, bool lrevers, long num_srch_cells, long srch_corners,
-                  const size_t *srch_add, const double *srch_corner_lat, const double *srch_corner_lon,
-                  bool *luse_last, double *intrsct_x, double *intrsct_y, int *avoid_pole_count, double *avoid_pole_offset)
+                  const size_t *srch_add, const double *srch_corner_lat, const double *srch_corner_lon, bool *luse_last,
+                  double *intrsct_x, double *intrsct_y, int *avoid_pole_count, double *avoid_pole_offset)
 {
   /*
     Intent(in):
@@ -98,7 +98,6 @@ pole_intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool
   double s1, s2, determ;                     /*  variables used for linear solve to   */
   double mat1, mat2, mat3, mat4, rhs1, rhs2; /* find intersection */
 
-
   /*printf("pole_intersection: %g %g %g %g\n", beglat, beglon, endlat,
    * endlon);*/
 
@@ -516,9 +515,9 @@ after_srch_loop:
 static void
 intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool *lcoinc, double beglat, double beglon, double endlat,
              double endlon, double *begseg, bool lbegin, bool lrevers, long num_srch_cells, long srch_corners,
-             const size_t *srch_add, const double *srch_corner_lat, const double *srch_corner_lon,
-             long *last_loc, bool *lthresh, double *intrsct_lat_off, double *intrsct_lon_off, bool *luse_last, double *intrsct_x,
-             double *intrsct_y, int *avoid_pole_count, double *avoid_pole_offset)
+             const size_t *srch_add, const double *srch_corner_lat, const double *srch_corner_lon, long *last_loc, bool *lthresh,
+             double *intrsct_lat_off, double *intrsct_lon_off, bool *luse_last, double *intrsct_x, double *intrsct_y,
+             int *avoid_pole_count, double *avoid_pole_offset)
 {
   /*
     Intent(in):
@@ -1007,8 +1006,9 @@ line_integral(double *weights, double in_phi1, double in_phi2, double theta1, do
 } /* line_integral */
 
 static void
-correct_pole(RemapGrid *src_grid, RemapGrid *tgt_grid, RemapVars &rv, std::vector<double> &src_centroid_lat, std::vector<double> &src_centroid_lon,
-             std::vector<double> &tgt_centroid_lat, std::vector<double> &tgt_centroid_lon, GridStore &grid_store)
+correct_pole(RemapGrid *src_grid, RemapGrid *tgt_grid, RemapVars &rv, std::vector<double> &src_centroid_lat,
+             std::vector<double> &src_centroid_lon, std::vector<double> &tgt_centroid_lat, std::vector<double> &tgt_centroid_lon,
+             GridStore &grid_store)
 {
   /*
      Correct for situations where N/S pole not explicitly included in
@@ -1222,7 +1222,7 @@ srvout(const char *fname, int nlon, int nlat, double *data)
   -----------------------------------------------------------------------
 */
 void
-remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
+remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 {
   RemapGrid *src_grid = rsearch.srcGrid;
   RemapGrid *tgt_grid = rsearch.tgtGrid;
@@ -1237,7 +1237,7 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
 
   double findex = 0;
 
-  if (Options::cdoVerbose) cdoPrint("Called %s()", __func__);
+  if (Options::cdoVerbose) cdo_print("Called %s()", __func__);
 
   progress::init();
 
@@ -1248,8 +1248,8 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
 
   if (Options::cdoVerbose)
     {
-      cdoPrint("North threshhold: %g", north_thresh);
-      cdoPrint("South threshhold: %g", south_thresh);
+      cdo_print("North threshhold: %g", north_thresh);
+      cdo_print("South threshhold: %g", south_thresh);
     }
 
   double start = Options::cdoVerbose ? cdo_get_wtime() : 0;
@@ -1262,14 +1262,14 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
 
   /* Initialize centroid arrays */
 
-  //double *src_centroid_lat = (double *) Malloc(src_grid_size * sizeof(double));
-  //double *src_centroid_lon = (double *) Malloc(src_grid_size * sizeof(double));
-  //double *tgt_centroid_lat = (double *) Malloc(tgt_grid_size * sizeof(double));
-  //double *tgt_centroid_lon = (double *) Malloc(tgt_grid_size * sizeof(double));
-  std::vector<double> src_centroid_lat (src_grid_size);
-  std::vector<double> src_centroid_lon (src_grid_size);
-  std::vector<double> tgt_centroid_lat (tgt_grid_size);
-  std::vector<double> tgt_centroid_lon (tgt_grid_size);
+  // double *src_centroid_lat = (double *) Malloc(src_grid_size * sizeof(double));
+  // double *src_centroid_lon = (double *) Malloc(src_grid_size * sizeof(double));
+  // double *tgt_centroid_lat = (double *) Malloc(tgt_grid_size * sizeof(double));
+  // double *tgt_centroid_lon = (double *) Malloc(tgt_grid_size * sizeof(double));
+  std::vector<double> src_centroid_lat(src_grid_size);
+  std::vector<double> src_centroid_lon(src_grid_size);
+  std::vector<double> tgt_centroid_lat(tgt_grid_size);
+  std::vector<double> tgt_centroid_lon(tgt_grid_size);
 
   for (long n = 0; n < src_grid_size; ++n)
     {
@@ -1296,8 +1296,8 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
       max_srch_cells[i] = 0;
     }
 
-  std::vector<size_t *> srch_add(Threading::ompNumThreads);  // global address of cells in srch arrays
-  for (i = 0; i < Threading::ompNumThreads; ++i) srch_add[i] = new size_t[tgt_grid_size];
+  Varray<Varray<size_t>> srch_add(Threading::ompNumThreads); // global address of cells in srch arrays
+  for (i = 0; i < Threading::ompNumThreads; ++i) srch_add[i].resize(tgt_grid_size);
 
   srch_corners = tgt_num_cell_corners;
 
@@ -1404,8 +1404,8 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
               /*  Prevent infinite loops if integration gets stuck near cell or threshold boundary */
               num_subseg++;
               if (num_subseg >= max_subseg)
-                cdoAbort("Integration stalled: num_subseg exceeded limit (grid1[%zu]: lon1=%g lon2=%g lat1=%g lat2=%g)!",
-                         src_cell_add, beglon, endlon, beglat, endlat);
+                cdo_abort("Integration stalled: num_subseg exceeded limit (grid1[%zu]: lon1=%g lon2=%g lat1=%g lat2=%g)!",
+                          src_cell_add, beglon, endlon, beglat, endlat);
 
               /* Uwe Schulzweida: skip very small regions */
               if (num_subseg % 1000 == 0)
@@ -1413,8 +1413,8 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
                   if (std::fabs(beglat - endlat) < 1.e-10 || std::fabs(beglon - endlon) < 1.e-10)
                     {
                       if (Options::cdoVerbose)
-                        cdoPrint("Skip very small region (grid1[%ld]): lon=%g dlon=%g lat=%g dlat=%g", src_cell_add, beglon,
-                                 endlon - beglon, beglat, endlat - beglat);
+                        cdo_print("Skip very small region (grid1[%ld]): lon=%g dlon=%g lat=%g dlat=%g", src_cell_add, beglon,
+                                  endlon - beglon, beglat, endlat - beglat);
                       break;
                     }
                 }
@@ -1422,7 +1422,7 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
               /* Find next intersection of this segment with a gridline on grid 2. */
 
               intersection(&tgt_cell_add, &intrsct_lat, &intrsct_lon, &lcoinc, beglat, beglon, endlat, endlon, begseg, lbegin,
-                           lrevers, num_srch_cells, srch_corners, srch_add[ompthID], srch_corner_lat[ompthID],
+                           lrevers, num_srch_cells, srch_corners, srch_add[ompthID].data(), srch_corner_lat[ompthID],
                            srch_corner_lon[ompthID], &last_loc, &lthresh, &intrsct_lat_off, &intrsct_lon_off, &luse_last,
                            &intrsct_x, &intrsct_y, &avoid_pole_count, &avoid_pole_offset);
 
@@ -1480,8 +1480,6 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
       free(srch_corner_lat[i]);
     }
 
-  for (i = 0; i < Threading::ompNumThreads; ++i) delete[] srch_add[i];
-
   /* Integrate around each cell on target grid */
 
   for (i = 0; i < Threading::ompNumThreads; ++i)
@@ -1491,7 +1489,7 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
     }
 
   for (i = 0; i < Threading::ompNumThreads; ++i) max_srch_cells[i] = 0;
-  for (i = 0; i < Threading::ompNumThreads; ++i) srch_add[i] = new size_t[src_grid_size];
+  for (i = 0; i < Threading::ompNumThreads; ++i) srch_add[i].resize(src_grid_size);
 
   srch_corners = src_num_cell_corners;
 
@@ -1598,8 +1596,8 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
               /*  Prevent infinite loops if integration gets stuck near cell or threshold boundary */
               num_subseg++;
               if (num_subseg >= max_subseg)
-                cdoAbort("Integration stalled: num_subseg exceeded limit (grid2[%zu]: lon1=%g lon2=%g lat1=%g lat2=%g)!",
-                         tgt_cell_add, beglon, endlon, beglat, endlat);
+                cdo_abort("Integration stalled: num_subseg exceeded limit (grid2[%zu]: lon1=%g lon2=%g lat1=%g lat2=%g)!",
+                          tgt_cell_add, beglon, endlon, beglat, endlat);
 
               /* Uwe Schulzweida: skip very small regions */
               if (num_subseg % 1000 == 0)
@@ -1607,8 +1605,8 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
                   if (std::fabs(beglat - endlat) < 1.e-10 || std::fabs(beglon - endlon) < 1.e-10)
                     {
                       if (Options::cdoVerbose)
-                        cdoPrint("Skip very small region (grid2[%ld]): lon=%g dlon=%g lat=%g dlat=%g", tgt_cell_add, beglon,
-                                 endlon - beglon, beglat, endlat - beglat);
+                        cdo_print("Skip very small region (grid2[%ld]): lon=%g dlon=%g lat=%g dlat=%g", tgt_cell_add, beglon,
+                                  endlon - beglon, beglat, endlat - beglat);
                       break;
                     }
                 }
@@ -1616,7 +1614,7 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
               /* Find next intersection of this segment with a gridline on grid 2. */
 
               intersection(&src_cell_add, &intrsct_lat, &intrsct_lon, &lcoinc, beglat, beglon, endlat, endlon, begseg, lbegin,
-                           lrevers, num_srch_cells, srch_corners, srch_add[ompthID], srch_corner_lat[ompthID],
+                           lrevers, num_srch_cells, srch_corners, srch_add[ompthID].data(), srch_corner_lat[ompthID],
                            srch_corner_lon[ompthID], &last_loc, &lthresh, &intrsct_lat_off, &intrsct_lon_off, &luse_last,
                            &intrsct_x, &intrsct_y, &avoid_pole_count, &avoid_pole_offset);
 
@@ -1679,8 +1677,6 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
       free(srch_corner_lat[i]);
     }
 
-  for (i = 0; i < Threading::ompNumThreads; ++i) delete[] srch_add[i];
-
   /*
      Correct for situations where N/S pole not explicitly included in
      grid (i.e. as a grid corner point). If pole is missing from only
@@ -1691,7 +1687,7 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
 
   grid_store_delete(grid_store);
 
-  if (rv.num_links != rv.max_links) remapVarsResize(rv, rv.num_links);
+  if (rv.num_links != rv.max_links) remap_vars_resize(rv, rv.num_links);
 
   /* Finish centroid computation */
 
@@ -1749,7 +1745,7 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
             }
         }
 
-     if ( Options::cdoVerbose ) cdoPrint("Removed number of links = %zu", rv.num_links -
+     if ( Options::cdoVerbose ) cdo_print("Removed number of links = %zu", rv.num_links -
   num_links);
 
       rv.num_links = num_links;
@@ -1761,7 +1757,7 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
 
   long num_links = rv.num_links;
 
-  if (Options::cdoVerbose) cdoPrint("Total number of links = %zu", rv.num_links);
+  if (Options::cdoVerbose) cdo_print("Total number of links = %zu", rv.num_links);
 
   for (long n = 0; n < src_grid_size; ++n)
     if (IS_NOT_EQUAL(src_grid->cell_area[n], 0)) src_grid->cell_frac[n] /= src_grid->cell_area[n];
@@ -1773,13 +1769,13 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
 
   if (lcheck)
     {
-      remapCheckArea(src_grid_size, &src_grid->cell_area[0], "Source");
-      remapCheckArea(tgt_grid_size, &tgt_grid->cell_area[0], "Target");
+      remap_check_area(src_grid_size, &src_grid->cell_area[0], "Source");
+      remap_check_area(tgt_grid_size, &tgt_grid->cell_area[0], "Target");
 
       for (long n = 0; n < src_grid_size; ++n)
         {
           if (src_centroid_lat[n] < -PIH - .01 || src_centroid_lat[n] > PIH + .01)
-            cdoPrint("Source grid centroid lat error: %ld %g", n, src_centroid_lat[n]);
+            cdo_print("Source grid centroid lat error: %ld %g", n, src_centroid_lat[n]);
 
           src_centroid_lat[n] = 0;
           src_centroid_lon[n] = 0;
@@ -1788,13 +1784,13 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
       for (long n = 0; n < tgt_grid_size; ++n)
         {
           if (tgt_centroid_lat[n] < -PIH - .01 || tgt_centroid_lat[n] > PIH + .01)
-            cdoPrint("Target grid centroid lat error: %ld %g", n, tgt_centroid_lat[n]);
+            cdo_print("Target grid centroid lat error: %ld %g", n, tgt_centroid_lat[n]);
 
           tgt_centroid_lat[n] = 0;
           tgt_centroid_lon[n] = 0;
         }
 
-      remapVarsCheckWeights(rv);
+      remap_vars_check_weights(rv);
 
       for (long n = 0; n < num_links; ++n)
         {
@@ -1814,9 +1810,9 @@ remapConservWeightsScrip(RemapSearch &rsearch, RemapVars &rv)
             norm_factor = tgt_grid->cell_area[n];
 
           if (tgt_centroid_lat[n] > 0 && std::fabs(tgt_centroid_lat[n] - norm_factor) > .01)
-            cdoPrint("Error: sum of wts for map1 %ld %g %g", n, tgt_centroid_lat[n], norm_factor);
+            cdo_print("Error: sum of wts for map1 %ld %g %g", n, tgt_centroid_lat[n], norm_factor);
         }
     }  // lcheck
 
-  if (Options::cdoVerbose) cdoPrint("Cells search: %.2f seconds", cdo_get_wtime() - start);
-}  // remapConservWeightsScrip
+  if (Options::cdoVerbose) cdo_print("Cells search: %.2f seconds", cdo_get_wtime() - start);
+}  // remap_conserv_weights_scrip
